#!/bin/sh
### BEGIN INIT INFO
# Provides:          Inconcert 
# Required-Start:    $local_fs $network $named $time $syslog
# Required-Stop:     $local_fs $network $named $time $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Description:       ElasticSearch Explorer - Monitoring system & time series database
### END INIT INFO

WORKING_DIR=/opt/elasticsearch_exporter
DAEMON=$WORKING_DIR/elasticsearch_exporter
NAME=elasticsearch_exporter
USER=root
PIDFILE=/var/run/elasticsearch_exporter/$NAME.pid
LOGFILE=/var/log/elasticsearch_exporter/$NAME.log

ARGS="--es.uri="http://<%=node.inconcert.elasticsearch_ip%>:9230" --web.listen-address=:9051 --es.all --es.indices --es.timeout 20s"

do_start_prepare()
{
  mkdir -p `dirname $PIDFILE` || true
  mkdir -p `dirname $LOGFILE` || true
  chown -R $USER: `dirname $LOGFILE`
  chown -R $USER: `dirname $PIDFILE`
}

do_start_cmd()
{
  do_start_prepare
  echo -n "Starting daemon: "$NAME
  start-stop-daemon --chdir $WORKING_DIR --chuid $USER -C --background --start --quiet --pidfile $PIDFILE --make-pidfile --exec $DAEMON -- $ARGS >> $LOGFILE 2>&1
  echo "."
}

do_stop_cmd()
{
  echo -n "Stopping daemon: "$NAME
  start-stop-daemon --stop --quiet --oknodo --pidfile $PIDFILE
  rm $PIDFILE
  echo "."
}

uninstall() {
  echo -n "Are you really sure you want to uninstall this service? That cannot be undone. [yes|No] "
  local SURE
  read SURE
  if [ "$SURE" = "yes" ]; then
    stop
    rm -f "$PIDFILE"
    echo "Notice: log file was not removed: '$LOGFILE'" >&2
    update-rc.d -f <NAME> remove
    rm -fv "$0"
  fi
}

status() {
  printf "%-50s" "Checking $NAME..."
  if [ -f $PIDFILE ]; then
    PID=$(cat $PIDFILE)
    if [ -z "$(ps axf | grep ${PID} | grep -v grep)" ]; then
      printf "%s\n" "The process appears to be dead but pidfile still exists"
    else    
      echo "Running, the PID is $PID"
    fi
  else
    printf "%s\n" "Service not running"
  fi
}


case "$1" in
  start)
    do_start_cmd
  ;;
  stop)
    do_stop_cmd
  ;;
    status)
    status
  ;;
  uninstall)
    uninstall
  ;;
  restart)
    do_stop_cmd
  do_start_cmd
  ;;
  *)
  echo "Usage: $1 {start|stop|status|restart|uninstall}"
  exit 1
esac

exit 0
